aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/armnn/Runtime.cpp15
1 files changed, 9 insertions, 6 deletions
diff --git a/src/armnn/Runtime.cpp b/src/armnn/Runtime.cpp
index 1abe0f394b..a91368140c 100644
--- a/src/armnn/Runtime.cpp
+++ b/src/armnn/Runtime.cpp
@@ -630,15 +630,18 @@ Status RuntimeImpl::EnqueueWorkload(NetworkId networkId,
auto status = loadedNetwork->EnqueueWorkload(inputTensors, outputTensors,
preImportedInputIds, preImportedOutputIds);
- ARMNN_LOG(info) << "Execution time: " << std::setprecision(2)
- << std::fixed << armnn::GetTimeDuration(startTime).count() << " ms.";
- // Call After EnqueueWorkload events
- for (auto&& context : m_BackendContexts)
+ // Check if we imported, if not there's no need to call the After EnqueueWorkload events
+ if (!preImportedInputIds.empty() || !preImportedOutputIds.empty())
{
- context.second->AfterEnqueueWorkload(networkId);
+ // Call After EnqueueWorkload events
+ for (auto&& context : m_BackendContexts)
+ {
+ context.second->AfterEnqueueWorkload(networkId);
+ }
}
-
+ ARMNN_LOG(info) << "Execution time: " << std::setprecision(2)
+ << std::fixed << armnn::GetTimeDuration(startTime).count() << " ms.";
return status;
}